@@ -1,3 +1,4 @@
+import django
 from django import forms, VERSION as django_version
 from django.template import Context
 from django.template.loader import get_template
@@ -60,7 +61,7 @@ def render(element, markup_classes):
     if element_type == 'boundfield':
         add_input_classes(element)
         template = get_template("bootstrapform/field.html")
-        context = Context({'field': element, 'classes': markup_classes, 'form': element.form})
+        context = {'field': element, 'classes': markup_classes, 'form': element.form}
     else:
         has_management = getattr(element, 'management_form', None)
         if has_management:
@@ -69,16 +70,17 @@ def render(element, markup_classes):
                     add_input_classes(field)
 
             template = get_template("bootstrapform/formset.html")
-            context = Context({'formset': element, 'classes': markup_classes})
+            context = {'formset': element, 'classes': markup_classes}
         else:
             for field in element.visible_fields():
                 add_input_classes(field)
 
             template = get_template("bootstrapform/form.html")
-            context = Context({'form': element, 'classes': markup_classes})
+            context = {'form': element, 'classes': markup_classes}
 
-        if django_version >= (1, 8):
-            context = context.flatten()
+
+    if django_version < (1, 8):
+        context = Context(context)
 
     return template.render(context)
 
